@@ -6,6 +6,7 @@ This utilizes ``flake8_nb.parser.cell_parsers``.
 import json
 import os
 import warnings
+from fnmatch import fnmatch
 from typing import Dict
 from typing import Iterator
 from typing import List
@@ -29,24 +30,20 @@ def ignore_cell(notebook_cell: Dict) -> bool:
     bool
         Whether cell should be ignored or not.
     """
-    if not notebook_cell["source"]:
-        return True
-    elif notebook_cell["cell_type"] != "code":
-        return True
-    else:
-        return False
+    return not notebook_cell["source"] or notebook_cell["cell_type"] != "code"
 
 
 class InvalidNotebookWarning(UserWarning):
     """Warning that is given when a jupyter notebook can't be parsed as JSON."""
 
-    def __init__(self, notebook_path: str, *args, **kwargs):
+    def __init__(self, notebook_path: str):
         """Initialize InvalidNotebookWarning.
 
         Parameters
         ----------
         notebook_path : str
             Path to a notebook
+
         """
         super().__init__(
             f"Error parsing notebook at path '{notebook_path}'. "
@@ -72,11 +69,13 @@ def read_notebook_to_cells(notebook_path: str) -> List[Dict]:
     -----
     InvalidNotebookWarning
         If the notebook couldn't be parsed.
+
+
+    .. # noqa: DAR402
     """
     try:
         with open(notebook_path, encoding="utf8") as notebook_file:
-            notebook_cells = json.load(notebook_file)["cells"]
-            return notebook_cells
+            return json.load(notebook_file)["cells"]
     except (json.JSONDecodeError, KeyError):
         warnings.warn(InvalidNotebookWarning(notebook_path))
         return []
@@ -95,8 +94,7 @@ def convert_source_line(source_line: str) -> str:
     Returns
     -------
     str
-        Valid python code, as string, even if it was a
-        jupyter magic line.
+        Valid python code, as string, even if it was a jupyter magic line.
     """
     if source_line.startswith(("!", "?", "%")) or source_line.endswith("?"):
         return ipython2python(source_line)
@@ -131,6 +129,9 @@ def get_notebook_code_cells(notebook_path: str) -> Tuple[bool, List[Dict]]:
     -----
     InvalidNotebookWarning
         If the notebook couldn't be parsed.
+
+
+    .. # noqa: DAR402
     """
     uses_get_ipython = False
     notebook_cells = read_notebook_to_cells(notebook_path)
@@ -164,18 +165,10 @@ def is_parent_dir(parent_dir: str, path: str) -> bool:
     -------
     bool
         Weather or not 'path' is inside of 'parent_dir'.
-
-    Notes
-    -----
-        This function uses `os.path.normcase` to prevent conflicts
-        in Windows path names.
     """
-    path = os.path.normcase(os.path.abspath(path))
-    parent_dir = os.path.normcase(os.path.abspath(parent_dir))
-    if path.startswith(parent_dir):
-        return True
-    else:
-        return False
+    path = os.path.abspath(path)
+    parent_dir = os.path.abspath(parent_dir)
+    return fnmatch(path, f"{parent_dir}*")
 
 
 def create_temp_path(notebook_path: str, temp_base_path: str) -> str:
@@ -248,6 +241,9 @@ def create_intermediate_py_file(
     -----
     InvalidNotebookWarning
         If the notebook couldn't be parsed.
+
+
+    .. # noqa: DAR402
     """
     intermediate_file_path = create_temp_path(notebook_path, intermediate_dir_base_path)
     uses_get_ipython, notebook_cells = get_notebook_code_cells(notebook_path)
